---
id: dev-roadmap
title: Roadmap to the Future
---

Bowler is still a very young project. There are many ways in which it could improve and
expand to cover more use cases.  Below is a non-exhaustive list of planned features
that are just waiting on someone to have the spare cycles to implement.

* Linting features, such as looking for and reporting lints, complete with recommended
  fixes from the CST. Supporting diff output in formats expected by common tools, like
  Phabricator, would make integration easier.

* Integration with common editors or IDE's like Nuclide, such as one-click renaming
  or encapsulation of attributes into properties.

* Comprehensive intermediate representations (IMR) for easier modification of syntax
  tree elements.

* More comprehensive set of default selectors, filters, and modifiers.

* Reduce boilerplate for executing queries or fixers.

* Better documentation for those unfamiliar with code refactoring.

If you're interested in working on these features, please read the [contributors][]
guide and open an issue on the Github repo to discuss it in more detail.

[contributors]: dev-intro
